@@ -5,16 +5,18 @@
 #############################################################################
 
 package Math::String::Charset::Grouped;
-use base Math::String::Charset;
-
-use vars qw($VERSION);
-$VERSION = '1.29';	# Current version of this package
-require  5.005;		# requires this Perl version or later
 
+require 5.005;		# requires this Perl version or later
 use strict;
+
+use base 'Math::String::Charset';
+
+our $VERSION;
+$VERSION = '1.30';	# Current version of this package
+
 use Math::BigInt;
 
-use vars qw/$die_on_error/;
+our $die_on_error;
 $die_on_error = 1;              # set to 0 to not die
 
 # following hash values are used:
@@ -253,7 +255,6 @@ sub is_valid
   return 0 if !defined $str;
   return 1 if $str eq '' && $self->{_minlen} <= 0;
 
-  my $int = Math::BigInt->bzero();
   my @chars;
   if (defined $self->{_sep})
     {
@@ -742,7 +743,7 @@ Returns the count of all possible strings described by the charset as a
 positive BigInt. Returns 'inf' if no maxlen is defined, because there should
 be no upper bound on how many strings are possible.
 
-If maxlen is defined, forces a calculation of all possible L<class()> values
+If maxlen is defined, forces a calculation of all possible L</class()> values
 and may therefore be very slow on the first call, it also caches possible
 lot's of values if maxlen is very high.
 
@@ -790,14 +791,14 @@ to (but much faster):
 	$order = $charset->order();
 
 Return the order of the charset: is always 1 for grouped charsets.
-See also L<type>.
+See also L</type()>.
 
 =item type()
 
 	$type = $charset->type();
 
 Return the type of the charset: is always 1 for grouped charsets.
-See also L<order>.
+See also L</order()>.
 
 =item charlen()
 
